<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="de_DE">
<context>
    <name>ArtisticSolidColor</name>
    <message>
        <source>Irregular</source>
        <translation>Unregelmäßigkeit</translation>
    </message>
    <message>
        <source>Horiz Offset</source>
        <translation>Horizontaler Offset</translation>
    </message>
    <message>
        <source>Vert Offset</source>
        <translation>Vertikaler Offset</translation>
    </message>
    <message>
        <source>Noise</source>
        <translation>Rauschen</translation>
    </message>
</context>
<context>
    <name>FlowLineStrokeStyle</name>
    <message>
        <source>Density</source>
        <translation type="unfinished">Dichte</translation>
    </message>
    <message>
        <source>Extension</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Width Scale</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Straighten Ends</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Flow Line</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MovingSolidColor</name>
    <message>
        <source>Offset</source>
        <translation>Offset</translation>
    </message>
    <message>
        <source>Horiz Offset</source>
        <translation>Horizontaler Offset</translation>
    </message>
    <message>
        <source>Vert Offset</source>
        <translation>Vertikaler Offset</translation>
    </message>
</context>
<context>
    <name>OutlineViewerStyle</name>
    <message>
        <source>OutlineViewer(OnlyDebug)</source>
        <translation>Umriss-Betrachter (Nur Debug)</translation>
    </message>
    <message>
        <source>Control Point</source>
        <translation>Kontrollpunkt</translation>
    </message>
    <message>
        <source>Center Line</source>
        <translation>Mittellinie</translation>
    </message>
    <message>
        <source>Outline Mode</source>
        <translation>Umriss-Modus</translation>
    </message>
    <message>
        <source>Distance</source>
        <translation>Distanz</translation>
    </message>
    <message>
        <source>distance</source>
        <translation>Abstand</translation>
    </message>
</context>
<context>
    <name>ShadowStyle</name>
    <message>
        <source>Hatched Shading</source>
        <translation>Schraffur</translation>
    </message>
    <message>
        <source>Angle</source>
        <translation>Winkel</translation>
    </message>
    <message>
        <source>Density</source>
        <translation>Dichte</translation>
    </message>
    <message>
        <source>Length</source>
        <translation>Länge</translation>
    </message>
</context>
<context>
    <name>ShadowStyle2</name>
    <message>
        <source>Plain Shadow</source>
        <translation>Schatten (Standard)</translation>
    </message>
    <message>
        <source>Angle</source>
        <translation>Winkel</translation>
    </message>
    <message>
        <source>Size</source>
        <translation>Größe</translation>
    </message>
</context>
<context>
    <name>TAirbrushRasterStyle</name>
    <message>
        <source>Airbrush</source>
        <translation>Airbrush</translation>
    </message>
    <message>
        <source>Blur value</source>
        <translation>Weichheitsgrad</translation>
    </message>
</context>
<context>
    <name>TBiColorStrokeStyle</name>
    <message>
        <source>Shade</source>
        <translation>Schattierung</translation>
    </message>
</context>
<context>
    <name>TBlendRasterStyle</name>
    <message>
        <source>Blend</source>
        <translation>Mischen</translation>
    </message>
</context>
<context>
    <name>TBlendStrokeStyle2</name>
    <message>
        <source>Fade</source>
        <translation>Einblendung</translation>
    </message>
    <message>
        <source>Border Fade</source>
        <translation>Rand-Blende</translation>
    </message>
    <message>
        <source>Fade In</source>
        <translation>Einblenden</translation>
    </message>
    <message>
        <source>Fade Out</source>
        <translation>Ausblenden</translation>
    </message>
</context>
<context>
    <name>TBraidStrokeStyle</name>
    <message>
        <source>Plait</source>
        <translation>Geflochten</translation>
    </message>
    <message>
        <source>Twirl</source>
        <translation>Wirbel</translation>
    </message>
</context>
<context>
    <name>TBubbleStrokeStyle</name>
    <message>
        <source>Bubbles</source>
        <translation>Blasen</translation>
    </message>
</context>
<context>
    <name>TChainStrokeStyle</name>
    <message>
        <source>Chain</source>
        <translation>Kette</translation>
    </message>
</context>
<context>
    <name>TChalkFillStyle</name>
    <message>
        <source>Chalk</source>
        <translation>Kreide</translation>
    </message>
    <message>
        <source>Density</source>
        <translation>Dichte</translation>
    </message>
    <message>
        <source>Dot Size</source>
        <translation>Punktgröße</translation>
    </message>
</context>
<context>
    <name>TChalkStrokeStyle2</name>
    <message>
        <source>Chalk</source>
        <translation>Kreide</translation>
    </message>
    <message>
        <source>Border Fade</source>
        <translation>Rand-Blende</translation>
    </message>
    <message>
        <source>Density</source>
        <translation>Dichte</translation>
    </message>
    <message>
        <source>Fade In</source>
        <translation>Einblenden</translation>
    </message>
    <message>
        <source>Fade Out</source>
        <translation>Ausblenden</translation>
    </message>
    <message>
        <source>Noise</source>
        <translation>Rauschen</translation>
    </message>
</context>
<context>
    <name>TCheckedFillStyle</name>
    <message>
        <source>Square</source>
        <translation>Quadrat</translation>
    </message>
    <message>
        <source>Horiz Dist</source>
        <translation>Horizontaler Abstand</translation>
    </message>
    <message>
        <source>Horiz Angle</source>
        <translation>Horizontaler Winkel</translation>
    </message>
    <message>
        <source>Vert Dist</source>
        <translation>Vertikaler Abstand</translation>
    </message>
    <message>
        <source>Vert Angle</source>
        <translation>Vertikaler Winkel</translation>
    </message>
    <message>
        <source>Thickness</source>
        <translation>Dicke</translation>
    </message>
</context>
<context>
    <name>TChessFillStyle</name>
    <message>
        <source>Chessboard</source>
        <translation>Schachbrett</translation>
    </message>
    <message>
        <source>Horiz Size</source>
        <translation>Horizontale Größe</translation>
    </message>
    <message>
        <source>Vert Size</source>
        <translation>Vertikale Größe</translation>
    </message>
    <message>
        <source>Angle</source>
        <translation>Winkel</translation>
    </message>
</context>
<context>
    <name>TCircleStripeFillStyle</name>
    <message>
        <source>Concentric</source>
        <translation>Konzentrisch</translation>
    </message>
    <message>
        <source>X Position</source>
        <translation>X-Position</translation>
    </message>
    <message>
        <source>Y Position</source>
        <translation>Y-Position</translation>
    </message>
    <message>
        <source>Distance</source>
        <translation>Distanz</translation>
    </message>
    <message>
        <source>Thickness</source>
        <translation>Dicke</translation>
    </message>
</context>
<context>
    <name>TCrystallizeStrokeStyle</name>
    <message>
        <source>Tulle</source>
        <translation>Tüll</translation>
    </message>
    <message>
        <source>Crease</source>
        <translation>Falte</translation>
    </message>
    <message>
        <source>Opacity</source>
        <translation>Opazität</translation>
    </message>
</context>
<context>
    <name>TDottedFillStyle</name>
    <message>
        <source>Polka Dots</source>
        <translation>Gepunktet</translation>
    </message>
    <message>
        <source>Dot Size</source>
        <translation>Punktgröße</translation>
    </message>
    <message>
        <source>Dot Distance</source>
        <translation>Punktdistanz</translation>
    </message>
</context>
<context>
    <name>TDottedLineStrokeStyle</name>
    <message>
        <source>Vanishing</source>
        <translation>Verdünnung</translation>
    </message>
    <message>
        <source>Fade In</source>
        <translation>Einblende</translation>
    </message>
    <message>
        <source>Dash</source>
        <translation>Gestrichelt</translation>
    </message>
    <message>
        <source>Fade Out</source>
        <translation>Ausblenden</translation>
    </message>
    <message>
        <source>Gap</source>
        <translation>Lücke</translation>
    </message>
</context>
<context>
    <name>TDualColorStrokeStyle2</name>
    <message>
        <source>Striped</source>
        <translation>Gestreift</translation>
    </message>
    <message>
        <source>Distance</source>
        <translation>Distanz</translation>
    </message>
</context>
<context>
    <name>TFriezeStrokeStyle2</name>
    <message>
        <source>Curl</source>
        <translation>Kringel</translation>
    </message>
    <message>
        <source>Twirl</source>
        <translation>Wirbel</translation>
    </message>
    <message>
        <source>Thickness</source>
        <translation>Dicke</translation>
    </message>
</context>
<context>
    <name>TFurStrokeStyle</name>
    <message>
        <source>Herringbone</source>
        <translation>Fischgrätenstich</translation>
    </message>
    <message>
        <source>Angle</source>
        <translation>Winkel</translation>
    </message>
    <message>
        <source>Size</source>
        <translation>Größe</translation>
    </message>
</context>
<context>
    <name>TGraphicPenStrokeStyle</name>
    <message>
        <source>Dashes</source>
        <translation>Strichelung</translation>
    </message>
    <message>
        <source>Density</source>
        <translation>Dichte</translation>
    </message>
</context>
<context>
    <name>TLinGradFillStyle</name>
    <message>
        <source>Linear Gradient</source>
        <translation>Linearer Verlauf</translation>
    </message>
    <message>
        <source>Angle</source>
        <translation>Winkel</translation>
    </message>
    <message>
        <source>X Position</source>
        <translation>X-Position</translation>
    </message>
    <message>
        <source>Y Position</source>
        <translation>Y-Position</translation>
    </message>
    <message>
        <source>Smoothness</source>
        <translation>Glätte</translation>
    </message>
</context>
<context>
    <name>TLongBlendStrokeStyle2</name>
    <message>
        <source>Watercolor</source>
        <translation>Wasserfarbe</translation>
    </message>
    <message>
        <source>Distance</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>TMatrioskaStrokeStyle</name>
    <message>
        <source>Toothpaste</source>
        <translation>Zahnpasta</translation>
    </message>
    <message>
        <source>Stripes</source>
        <translation>Streifen</translation>
    </message>
</context>
<context>
    <name>TMosaicFillStyle</name>
    <message>
        <source>Stained Glass</source>
        <translation>Farbglas</translation>
    </message>
    <message>
        <source>Size</source>
        <translation>Größe</translation>
    </message>
    <message>
        <source>Distortion</source>
        <translation>Verzerrung</translation>
    </message>
    <message>
        <source>Min Thick</source>
        <translation>Minimale Dicke</translation>
    </message>
    <message>
        <source>Max Thick</source>
        <translation>Maximale Dicke</translation>
    </message>
</context>
<context>
    <name>TMultiLineStrokeStyle2</name>
    <message>
        <source>Gouache</source>
        <translation>Gouache</translation>
    </message>
    <message>
        <source>Density</source>
        <translation>Dichte</translation>
    </message>
    <message>
        <source>Size</source>
        <translation>Größe</translation>
    </message>
    <message>
        <source>Thickness</source>
        <translation>Dicke</translation>
    </message>
    <message>
        <source>Noise</source>
        <translation>Rauschen</translation>
    </message>
</context>
<context>
    <name>TNoColorRasterStyle</name>
    <message>
        <source>Markup</source>
        <translation>Markierung</translation>
    </message>
</context>
<context>
    <name>TNormal2StrokeStyle</name>
    <message>
        <source>Bump</source>
        <translation>Beule</translation>
    </message>
    <message>
        <source>Light X Pos</source>
        <translation>Licht X-Position</translation>
    </message>
    <message>
        <source>Light Y Pos</source>
        <translation>Licht Y-Position</translation>
    </message>
    <message>
        <source>Shininess</source>
        <translation>Glanz</translation>
    </message>
    <message>
        <source>Plastic</source>
        <translation>Plastik</translation>
    </message>
</context>
<context>
    <name>TPatchFillStyle</name>
    <message>
        <source>Beehive</source>
        <translation>Bienenwaben</translation>
    </message>
    <message>
        <source>Size</source>
        <translation>Größe</translation>
    </message>
    <message>
        <source>Distortion</source>
        <translation>Verzerrung</translation>
    </message>
    <message>
        <source>Thickness</source>
        <translation>Dicke</translation>
    </message>
</context>
<context>
    <name>TPointShadowFillStyle</name>
    <message>
        <source>Sponge Shading</source>
        <translation>Schwammschattierung</translation>
    </message>
    <message>
        <source>Angle</source>
        <translation>Winkel</translation>
    </message>
    <message>
        <source>Density</source>
        <translation>Dichte</translation>
    </message>
    <message>
        <source>Size</source>
        <translation>Größe</translation>
    </message>
    <message>
        <source>Point Size</source>
        <translation>Punktgröße</translation>
    </message>
</context>
<context>
    <name>TRadGradFillStyle</name>
    <message>
        <source>Radial Gradient</source>
        <translation>Radialer Verlauf</translation>
    </message>
    <message>
        <source>X Position</source>
        <translation>X-Position</translation>
    </message>
    <message>
        <source>Y Position</source>
        <translation>Y-Position</translation>
    </message>
    <message>
        <source>Radius</source>
        <translation>Radius</translation>
    </message>
    <message>
        <source>Smoothness</source>
        <translation>Glätte</translation>
    </message>
</context>
<context>
    <name>TRopeStrokeStyle</name>
    <message>
        <source>Rope</source>
        <translation>Seil</translation>
    </message>
    <message>
        <source>Tilt</source>
        <translation>Neigung</translation>
    </message>
</context>
<context>
    <name>TRubberFillStyle</name>
    <message>
        <source>Blob</source>
        <translation>Klecks</translation>
    </message>
    <message>
        <source>Intensity</source>
        <translation>Intensität</translation>
    </message>
</context>
<context>
    <name>TSawToothStrokeStyle</name>
    <message>
        <source>Jagged</source>
        <translation>Gezackt</translation>
    </message>
    <message>
        <source>Distance</source>
        <translation>Distanz</translation>
    </message>
</context>
<context>
    <name>TSinStrokeStyle</name>
    <message>
        <source>Wave</source>
        <translation>Welle</translation>
    </message>
    <message>
        <source>Frequency</source>
        <translation>Frequenz</translation>
    </message>
</context>
<context>
    <name>TSketchStrokeStyle</name>
    <message>
        <source>Fuzz</source>
        <translation>Flaum</translation>
    </message>
    <message>
        <source>Density</source>
        <translation>Dichte</translation>
    </message>
</context>
<context>
    <name>TSprayStrokeStyle</name>
    <message>
        <source>Circlets</source>
        <translation>Kreischen</translation>
    </message>
    <message>
        <source>Border Fade</source>
        <translation>Rand-Blende</translation>
    </message>
    <message>
        <source>Density</source>
        <translation>Dichte</translation>
    </message>
    <message>
        <source>Size</source>
        <translation>Größe</translation>
    </message>
</context>
<context>
    <name>TStripeFillStyle</name>
    <message>
        <source>Banded</source>
        <translation>Gebändert</translation>
    </message>
    <message>
        <source>Distance</source>
        <translation>Distanz</translation>
    </message>
    <message>
        <source>Angle</source>
        <translation>Winkel</translation>
    </message>
    <message>
        <source>Thickness</source>
        <translation>Dicke</translation>
    </message>
</context>
<context>
    <name>TTissueStrokeStyle</name>
    <message>
        <source>Gauze</source>
        <translation>Gaze</translation>
    </message>
    <message>
        <source>Density</source>
        <translation>Dichte</translation>
    </message>
    <message>
        <source>Border Size</source>
        <translation>Randgröße</translation>
    </message>
</context>
<context>
    <name>TTwirlStrokeStyle</name>
    <message>
        <source>Ribbon</source>
        <translation>Schleife</translation>
    </message>
    <message>
        <source>Twirl</source>
        <translation>Wirbel</translation>
    </message>
    <message>
        <source>Shade</source>
        <translation>Schattierung</translation>
    </message>
</context>
<context>
    <name>TZigzTSinStrokeStyleagStrokeStyle</name>
    <message>
        <source>Thickness</source>
        <translation>Dicke</translation>
    </message>
</context>
<context>
    <name>TZigzagStrokeStyle</name>
    <message>
        <source>Zigzag</source>
        <translation>Zick-Zack</translation>
    </message>
    <message>
        <source>Min Distance</source>
        <translation>Minimale Distanz</translation>
    </message>
    <message>
        <source>Max Distance</source>
        <translation>Maximale Distanz</translation>
    </message>
    <message>
        <source>Min Angle</source>
        <translation>Minimaler Winkel</translation>
    </message>
    <message>
        <source>Max Angle</source>
        <translation>Maximaler Winkel</translation>
    </message>
    <message>
        <source>Thickness</source>
        <translation>Dicke</translation>
    </message>
</context>
</TS>
